@@ -25,7 +25,7 @@ test_that("cache incrementally expires old values", {
   expect_equal(100, store("foo", 100))
 })
 
-test_that("cache expires least recently accessed values", {
+test_that("lru_cache expires least recently accessed values", {
   store <- lru_cache(3)
   store("foo", 1)
   store("bar", 2)
@@ -41,6 +41,15 @@ test_that("cache expires least recently accessed values", {
   expect_equal(200, store("baz", 200))
 })
 
+test_that("permanent_cache does not expire values", {
+  store <- permanent_cache()
+  for (i in 1:10001) {
+    store(as.character(i), i)
+  }
+  fn <- memo(identity, cache=store)
+  cache_stats(fn)$used %is% 10001
+})
+
 test_that("cache_stats extracts stats", {
   fib <- function(x) if (x <= 1) 1 else fib(x-1) + fib(x-2)
   fib <- memo(fib, key=pointer_key)
